@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: info.c,v 1.16 2002/01/19 23:00:07 dspiljar Exp $ */
+  $Id: info.c,v 1.19 2003/04/13 19:15:58 dspiljar Exp $ */
 
 #include <config.h>
 
@@ -25,11 +25,30 @@
 
 #include "mboxgrep.h"
 
+
+void
+print_wrap (char *str, int len, int *n)
+     /* {{{  */
+{
+  *n += len;
+  fprintf (stdout, str);
+  if (*n >= 50)
+    {
+      fprintf (stdout, "\n");
+      *n = 0;
+    }
+  else fprintf (stdout, " ");
+}
+/* }}} */
+
 void
 version (void)
+     /* {{{  */
 {
+  int n = 0;
+
   fprintf (stdout, "%s %s\n\n"
-	   "Copyright (C) 2000, 2001, 2002  Daniel Spiljar\n"
+	   "Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar\n"
 	   "This program is free software; you can redistribute it and/or "
 	   "modify\nit under the terms of the GNU General Public License "
 	   "as published by\nthe Free Software Foundation; either version "
@@ -37,45 +56,50 @@ version (void)
 	   APPNAME, VERSION);
   fprintf (stdout, "Compilation options:\n");
 #ifdef HAVE_DIRENT_H
-  fprintf (stdout, "HAVE_DIRENT_H ");
+  print_wrap ("HAVE_DIRENT_H", 13, &n);
 #endif /* HAVE_DIRENT_H */
 #ifdef HAVE_FCNTL
-  fprintf (stdout, "HAVE_FCNTL ");
+  print_wrap ("HAVE_FCNTL", 10, &n);
 #endif /* HAVE_FCNTL */
 #ifdef HAVE_FLOCK
-  fprintf (stdout, "HAVE_FLOCK ");
+  print_wrap ("HAVE_FLOCK", 10, &n);
 #endif /* HAVE_FLOCK */
 #ifdef HAVE_FTS_OPEN
-  fprintf (stdout, "HAVE_FTS_OPEN ");
+  print_wrap ("HAVE_FTS_OPEN", 13, &n);
 #else
 # ifdef HAVE_FTW
-  fprintf (stdout, "HAVE_FTW ");
+  print_wrap ("HAVE_FTW", 8, &n);
 # endif /* HAVE_FTW */
 #endif /* HAVE_FTS_OPEN */
 /*
   fprintf (stdout, "HAVE_LIBLOCKFILE ");
 */
 #ifdef HAVE_LIBPCRE
-  fprintf (stdout, "HAVE_LIBPCRE ");
+  print_wrap ("HAVE_LIBPCRE", 12, &n);
 #endif /* HAVE_LIBPCRE */
 #ifdef HAVE_LIBZ
-  fprintf (stdout, "HAVE_LIBZ ");
+  print_wrap ("HAVE_LIBZ", 9, &n);
 #endif /* HAVE_LIBZ */
+#ifdef HAVE_LIBBZ2
+  print_wrap ("HAVE_LIBBZ2", 11, &n);
+#endif /* HAVE_LIBBZ2 */
 #ifdef HAVE_NDIR_H
-  fprintf (stdout, "HAVE_NDIR_H ");
+  print_wrap ("HAVE_NDIR_H", 11, &n);
 #endif /* HAVE_NDIR_H */
 #ifdef HAVE_SYS_DIR_H
-  fprintf (stdout, "HAVE_SYS_DIR_H ");
+  print_wrap ("HAVE_SYS_DIR_H", 14, &n);
 #endif /* HAVE_SYS_DIR_H */
 #ifdef HAVE_SYS_NDIR_H
-  fprintf (stdout, "HAVE_SYS_NDIR_H ");
+  print_wrap ("HAVE_SYS_NDIR_H", 15, &n);
 #endif
   fprintf (stdout, "\n");
   exit(0);
 }
+/* }}} */
 
 void 
 help (void)
+     /* {{{  */
 {
   fprintf(stdout, "%s %s - search MAILBOX for messages matching PATTERN\n\n",
 	  APPNAME, VERSION);
@@ -130,11 +154,15 @@ help (void)
 
   exit(0);
 }
+/* }}} */
 
 void 
 usage (void)
+     /* {{{  */
 {
   printf ("Usage: %s [OPTION] PATTERN MAILBOX ...\n\n"
           "Try `%s --help' for more information.\n", APPNAME, APPNAME);
   exit (2);
 }
+/* }}} */
+
