@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: maildir.c,v 1.16 2002/02/06 22:10:44 dspiljar Exp $ */
+  $Id: maildir.c,v 1.21 2003/03/30 23:07:10 dspiljar Exp $ */
 
 #include <config.h>
 
@@ -52,6 +52,10 @@
 #include "maildir.h"
 #include "wrap.h"
 
+#ifdef HAVE_LIBDMALLOC
+#include <dmalloc.h>
+#endif /* HAVE_LIBDMALLOC */
+
 maildir_t *
 maildir_open (const char *path)
 {
@@ -111,7 +115,8 @@ message_t *
 maildir_read_message (maildir_t *mdp)
 {
   int isheaders = 1;
-  int have_from = 0, have_to = 0, have_message_id = 0, have_return_path = 0;
+  int have_from = 0, have_to = 0, have_message_id = 0, have_return_path = 0,
+    have_sender = 0, have_date = 0;
   static message_t *message;
   static struct dirent *d_content;
   char *filename, buffer[BUFSIZ];
@@ -129,6 +134,8 @@ maildir_read_message (maildir_t *mdp)
   message->body[0] = '\0';
   message->bbytes = 0;
 
+  message->from = NULL;
+
   for(;;)
     {
       if (mdp->new != NULL) 
@@ -192,10 +199,12 @@ maildir_read_message (maildir_t *mdp)
 	    } /* if */
 	  if (isheaders)
 	    {
-	      if (0 == strncasecmp ("Date: ", buffer, 6) && isheaders == 1)
-		message->date = parse_date(buffer);
 	      if (0 == strncasecmp ("From: ", buffer, 6))
 		have_from = 1;
+	      if (0 == strncasecmp ("Sender: ", buffer, 8))
+		have_sender = 1;
+	      if (0 == strncasecmp ("Date: ", buffer, 6))
+		have_date = 1;
 	      if (0 == strncasecmp ("To: ", buffer, 4))
 		have_to = 1;
 	      if (0 == strncasecmp ("Message-ID: ", buffer, 12))
@@ -221,7 +230,8 @@ maildir_read_message (maildir_t *mdp)
 	      message->bbytes += s;
 	    } /* else */
 	} /* while */
-      if (!have_from || !have_to || !have_message_id)
+/*       if (!have_from || !have_to || !have_message_id) */
+      if ((!have_from && !have_sender)|| !have_date)
 	{
 	  if (config.merr)
 	    fprintf(stderr, "%s: %s: Not a RFC 2822 message\n", 
@@ -238,8 +248,7 @@ maildir_read_message (maildir_t *mdp)
 void 
 maildir_write_message (message_t *m, const char *path)
 {
-  extern int pid, maildir_count;
-  extern char hostname[BUFSIZ];
+  extern int maildir_count;
   char bla[BUFSIZ], *s1, *s2;
   int t;
   static FILE *f1;
@@ -247,7 +256,7 @@ maildir_write_message (message_t *m, const char *path)
   maildir_count++;
   t = (int) time (NULL);
 
-  sprintf (bla, "%i.%i_%i.%s", t, pid, maildir_count, hostname);
+  sprintf (bla, "%i.%i_%i.%s", t, config.pid, maildir_count, config.hostname);
   s1 = (char *) xmalloc ((strlen (path) + strlen (bla) + 6) * sizeof (char));
   sprintf(s1, "%s/tmp/%s", path, bla);
   s2 = (char *) xmalloc ((strlen (path) + strlen (bla) + 6) * sizeof (char));
