@@ -1,6 +1,6 @@
-/* -*- C -*- 
+/* -*- C -*-
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,24 +16,17 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: main.c,v 1.22 2002/02/08 00:56:29 dspiljar Exp $ */
+  $Id: main.c,v 1.32 2003/08/24 19:23:50 dspiljar Exp $ */
 
 #include <config.h>
 
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <regex.h>
 #include <stdlib.h>
 #include <unistd.h>
-#ifdef HAVE_FTS_OPEN
-# include <sys/stat.h>
-# include <fts.h>
-#else
-# ifdef HAVE_FTW
-#  include <ftw.h>
-# endif /* HAVE_FTW */
-#endif /* HAVE_FTS_OPEN */
 #ifdef HAVE_LIBPCRE
 #include <pcre.h>
 #endif /* HAVE_LIBPCRE */
@@ -50,27 +43,25 @@
 #include "scan.h"
 #include "wrap.h" /* xcalloc() et cetera */
 
+#ifdef HAVE_LIBDMALLOC
+#include <dmalloc.h>
+#endif /* HAVE_LIBDMALLOC */
+
 regex_t posix_pattern;
 #ifdef HAVE_LIBPCRE
 pcre *pcre_pattern;
 pcre_extra *hints;
 #endif /* HAVE_LIBPCRE */
-char *boxname, *outboxname, *pipecmd, *tmpfilename, hostname[BUFSIZ];
-int pid, maildir_count = 0;
+char *boxname, *outboxname, *pipecmd, *tmpfilename;
+int maildir_count = 0;
 int count = 0;
-FILE *tmpp;
-#ifdef HAVE_LIBZ
-gzFile *ztmpp;
-#endif /* HAVE_LIBZ */
+void *tmpp;
 checksum_t *cs;
 
-#ifdef HAVE_FTS_OPEN
-FTS *ftsfoo;
-FTSENT *ftsbar;
-#endif /* HAVE_FTS_OPEN */
-
 int
 main (int argc, char **argv)
+     /* {{{  */
+
 {
   int option_index = 0;
   int c;
@@ -85,31 +76,36 @@ main (int argc, char **argv)
   int errcode = 0;
   char errbuf[BUFSIZ];
 
-  static struct option long_options[] = {
-    {"count", 0, 0, 'c'},
-    {"delete", 0, 0, 'd'},
-/*  {"date", 1, 0, 'D'}, */
-    {"extended-regexp", 0, 0, 'E'},
-    {"basic-regexp", 0, 0, 'G'},
-    {"perl-regexp", 0, 0, 'P'},
-    {"help", 0, 0, 'h'},
-    {"ignore-case", 0, 0, 'i'},
-    {"mailbox-format", 1, 0, 'm'},
-    {"no", 1, 0, 'n' },
-    {"pipe", 1, 0, 'p'},
-    {"regexp", 1, 0, 'e'},
-    {"invert-match", 0, 0, 'v'},
-    {"version", 0, 0, 'V'},
-    {"headers", 0, 0, 'H'},
-    {"body", 0, 0, 'B'},
-    {"no-messages", 0, 0, 's'},
-    {"output", 1, 0, 'o'},
-    {"no-duplicates", 0, 0, 200},
-    {"no-file-lock", 0, 0, 201},
-    {"file-lock", 1, 0, 'l'},
-    {"recursive", 0, 0, 'r'},
-    {0, 0, 0, 0}
-  };
+  static struct option long_options[] = 
+    /* {{{  */
+
+    {
+      {"count", 0, 0, 'c'},
+      {"delete", 0, 0, 'd'},
+      /*  {"date", 1, 0, 'D'}, */
+      {"extended-regexp", 0, 0, 'E'},
+      {"basic-regexp", 0, 0, 'G'},
+      {"perl-regexp", 0, 0, 'P'},
+      {"help", 0, 0, 'h'},
+      {"ignore-case", 0, 0, 'i'},
+      {"mailbox-format", 1, 0, 'm'},
+      {"no", 1, 0, 'n' },
+      {"pipe", 1, 0, 'p'},
+      {"regexp", 1, 0, 'e'},
+      {"invert-match", 0, 0, 'v'},
+      {"version", 0, 0, 'V'},
+      {"headers", 0, 0, 'H'},
+      {"body", 0, 0, 'B'},
+      {"no-messages", 0, 0, 's'},
+      {"output", 1, 0, 'o'},
+      {"no-duplicates", 0, 0, 200},
+      {"no-file-lock", 0, 0, 201},
+      {"file-lock", 1, 0, 'l'},
+      {"recursive", 0, 0, 'r'},
+      {0, 0, 0, 0}
+    };
+
+  /* }}} */
 
   config.perl = 0;
   config.extended = 1;
@@ -133,6 +129,8 @@ main (int argc, char **argv)
 	break;
 
       switch (c)
+	/* {{{  */
+
 	{
 	case '?':
 	  usage();
@@ -224,6 +222,8 @@ main (int argc, char **argv)
 	      }
 	  }
 	} /* switch */
+
+      /* }}} */
     } /* while */
 
   if ((config.body == 0) && (config.headers == 0))
@@ -234,8 +234,8 @@ main (int argc, char **argv)
 
   if (config.format == MAILDIR && config.action == WRITE)
     {
-      gethostname (hostname, BUFSIZ);
-      pid = (int) getpid ();
+      gethostname (config.hostname, HOST_NAME_SIZE);
+      config.pid = (int) getpid ();
     }
 
   cs = (checksum_t *) xmalloc (sizeof (checksum_t));
@@ -253,6 +253,8 @@ main (int argc, char **argv)
     {
 #ifdef HAVE_LIBPCRE
       if (config.perl)
+	/* {{{  */
+
 	{
 	  pcre_pattern = pcre_compile (regex_s, 
 				       (config.ignorecase ? PCRE_CASELESS : 0),
@@ -264,8 +266,12 @@ main (int argc, char **argv)
 	      exit(2);
 	    }
 	}
+
+      /* }}} */
       else
 #endif /* HAVE_LIBPCRE */
+	/* {{{  */
+
 	{
 	  int flag1 = 0, flag2 = 0;
 	  
@@ -273,7 +279,7 @@ main (int argc, char **argv)
 	    flag1 = REG_ICASE;
 	  if (config.extended)
 	    flag2 = REG_EXTENDED;
-	  
+	
 	  errcode = regcomp (&posix_pattern, regex_s, 
 			     (flag1 | flag2 | REG_NEWLINE ));
 	  if (0 != errcode)
@@ -286,6 +292,8 @@ main (int argc, char **argv)
 	      exit (2);
 	    } /* if */
 	} /* if */
+
+      /* }}} */
     } /* if */
   else
     usage ();
@@ -294,44 +302,31 @@ main (int argc, char **argv)
     singlefile = 1;
 
   while (optind < argc)
+    /* {{{  */
+
     {
-      if (config.action == DELETE)
-	{
-#ifdef HAVE_LIBZ
-	  if (config.format == ZMBOX)
-	    ztmpp = gztmpfile_open ();
-#endif /* HAVE_LIBZ */
-	  if (config.format == MBOX)
-	    tmpp = tmpfile_open ();
-	}
+      if (config.action == DELETE) {
+	  tmpp = tmpfile_open (argv[optind]);
+
+	  /* If we're root, copy {owner, group, perms} of mailbox to the tmpfile
+	   * so rename() will thus retain the original's ownership & permissions.
+	   */
+	  if (geteuid() == 0) {
+	      struct stat s;
+	      if (stat(argv[optind], &s) != -1) {
+		  if (fchown(fileno(tmpp), s.st_uid, s.st_gid) == -1)
+		      if (config.merr) perror(tmpfilename);
+		  if (fchmod(fileno(tmpp), s.st_mode) == -1)
+		      if (config.merr) perror(tmpfilename);
+	      }
+	      else if (config.merr) perror(argv[optind]);
+	  }
+      }
 
       boxname = xstrdup (argv[optind]);
 
       if (config.recursive)
-#ifdef HAVE_FTS_OPEN
-	{
-	  char *p[2];
-
-	  p[0] = strdup (argv[optind]);
-	  p[1] = 0;
-
-	  ftsfoo = fts_open (p, FTS_NOCHDIR, NULL);
-
-	  if (ftsfoo == NULL)
-	    {
-	      /* fixme (?) */
-	      perror(APPNAME);
-	      exit (2);
-	    }
-
-	  while (ftsbar = fts_read (ftsfoo))
-	    scan_mailbox (ftsbar->fts_path);
-
-	  fts_close (ftsfoo);
-	}
-#else
-	ftw (argv[optind], (void *) scan_mailbox, 1);
-#endif /* HAVE_FTS_OPEN */
+	recursive_scan (argv[optind]);
       else
 	scan_mailbox (argv[optind]);
       havemailbox = 1;
@@ -340,13 +335,18 @@ main (int argc, char **argv)
 	  if (singlefile)
 	    fprintf (stdout, "%i\n", count);
 	  else
-	    fprintf (stdout, "%s:%i\n", argv[optind], count);
+	    {
+	      if (0 == strcmp ("-", argv[optind]))
+		fprintf (stdout, "(standard input):%i\n", count);
+	      else
+		fprintf (stdout, "%s:%i\n", argv[optind], count);
+	    }
 	}
       if (config.action == DELETE)
 	{
 #ifdef HAVE_LIBZ
 	  if (config.format == ZMBOX)
-	    gzclose (ztmpp);
+	    gzclose (tmpp);
 #endif /* HAVE_LIBZ */
 	  if (config.format == MBOX)
 	    fclose (tmpp);
@@ -355,8 +355,21 @@ main (int argc, char **argv)
       ++optind;
     } /* while */
 
+  /* }}} */
+
   if (! havemailbox)
-    usage ();
+    /* {{{  */
+
+    {
+      config.format = MBOX;
+      scan_mailbox ("-");
+      if (config.action == COUNT)
+	fprintf (stdout, "%i\n", count);
+    }
+
+  /* }}} */
 
   return 0;
 } /* main */
+
+/* }}} */
