@@ -1,6 +1,6 @@
 /* -*- C -*- 
    mboxgrep - scan mailbox for messages matching a regular expression
-   Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+   Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
    
    Mboxgrep is free software; you can redistribute it and/or modify it 
    under the terms of the GNU General Public License as published by
@@ -16,41 +16,26 @@
    along with mboxgrep; if not, write to the Free Software Foundation, 
    Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    
-   $Id: mbox.h,v 1.4 2002/01/19 20:30:06 dspiljar Exp $ */
+   $Id: mbox.h,v 1.9 2003/08/24 19:23:50 dspiljar Exp $ */
 
 #ifndef MBOX_H
 #define MBOX_H 1
 
 #include <config.h>
 
-#include <stdio.h>		/* for FILE structure */
-#ifdef HAVE_LIBZ
-#include <zlib.h>               /* for gzFile structure */
-#endif /* HAVE_LIBZ */
-
 #include "mboxgrep.h"           /* for message_t structure */
 
-/* open a mbox folder and lock it */
-FILE *mbox_open (const char *path, const char *mode);
-/* open a temporary file for writing */
-FILE *tmpfile_open(void);
-/* unlock the mbox folder and close it */
-void mbox_close (FILE * fp);
-/* read a message from a mbox folder */
-message_t *mbox_read_message (FILE * fp);
+typedef struct
+{
+  void *fp;
+  void *fp_raw;
+  char *postmark_cache;
+} mbox_t;
 
-#ifdef HAVE_LIBZ
 
-/* open a compressed mbox folder and lock it */
-gzFile *gzmbox_open (const char *path, const char *mode);
-
-gzFile *gztmpfile_open (void);
-
-/* read a message from a compressed mbox folder */
-message_t *gzmbox_read_message (gzFile * fp);
-/* unlock the compressed mbox folder and close it */
-void gzmbox_close (gzFile * fp);
-
-#endif /* HAVE_LIBZ */
+mbox_t *mbox_open (const char *path, const char *mode);
+void *tmpfile_open (const char *path);
+void mbox_close (mbox_t * mbp);
+message_t *mbox_read_message (mbox_t * mbp);
 
 #endif /* MBOX_H */
