@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,14 +16,16 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: mboxgrep.h,v 1.14 2002/02/08 00:56:30 dspiljar Exp $ */
+  $Id: mboxgrep.h,v 1.21 2003/04/06 21:01:49 dspiljar Exp $ */
 
 #ifndef MBOXGREP_H
 #define MBOXGREP_H
 
 #define APPNAME "mboxgrep"
-#define VERSION "0.7.6a"
-#define BUGREPORT_ADDR "dspiljar+mboxgrep@bofhlet.net"
+#define VERSION "0.7.9"
+#define BUGREPORT_ADDR "dspiljar@world.std.com"
+
+#define HOST_NAME_SIZE 256
 
 #include <config.h>
 
@@ -31,10 +33,7 @@
 
 #ifdef HAVE_DIRENT_H
 # include <dirent.h>
-# define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
-# define dirent direct
-# define NAMLEN(dirent) (dirent)->d_namlen
 # ifdef HAVE_SYS_NDIR_H
 #  include <sys/ndir.h>
 # endif /* HAVE_SYS_NDIR_H */
@@ -54,7 +53,8 @@ typedef enum
     MH,
     NNML,
     NNMH,
-    MAILDIR
+    MAILDIR,
+    BZ2MBOX
   }
 format_t;
 
@@ -119,6 +119,9 @@ typedef struct
   int count;
   int ignorecase;
   int merr;
+  int pid;
+
+  char hostname[HOST_NAME_SIZE];
 
   action_t action;
   format_t format;
