@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: mh.c,v 1.10 2002/02/06 22:10:44 dspiljar Exp $ */
+  $Id: mh.c,v 1.15 2003/03/30 23:07:10 dspiljar Exp $ */
 
 #include <stdio.h>
 #include <string.h>
@@ -48,6 +48,10 @@
 #include "mh.h"
 #include "wrap.h"
 
+#ifdef HAVE_LIBDMALLOC
+# include <dmalloc.h>
+#endif /* HAVE_LIBDMALLOC */
+
 extern option_t config;
 
 DIR *mh_open (const char *path)
@@ -76,7 +80,8 @@ void mh_close (DIR *dp)
 message_t *mh_read_message (DIR *dp)
 {
   int isheaders = 1;
-  int have_from = 0, have_to = 0, have_message_id = 0, have_return_path = 0;
+  int have_from = 0, have_return_path = 0,
+    have_date = 0, have_sender = 0;
   static int s;
   message_t *message;
   struct dirent *d_content;
@@ -86,14 +91,16 @@ message_t *mh_read_message (DIR *dp)
 
   message = (message_t *) xmalloc (sizeof (message_t));
 
-  message->headers = (char *) xmalloc (sizeof (char));
-  message->headers[0] = '\0';
+  message->headers = NULL;
   message->hbytes = 0;
 
-  message->body = (char *) xmalloc (sizeof (char));
-  message->body[0] = '\0';
+  message->body = NULL;
   message->bbytes = 0;
 
+  message->from = NULL;
+
+  filename = NULL;
+
   for(;;)
     {
       d_content = readdir(dp);
@@ -101,31 +108,48 @@ message_t *mh_read_message (DIR *dp)
       if (d_content->d_name[0] == '.')
 	continue;
 
-      filename = 
-	(char *) xmalloc ((strlen (d_content->d_name)) + 
-			  (strlen (boxname)) + 2);
+      filename = (char *) xrealloc 
+	(filename, ((strlen (d_content->d_name)) + 
+		    (strlen (boxname)) + 2));
+
+/*       message->headers = (char *) xrealloc (message->headers, 0); */
+/*       message->hbytes = 0; */
+/*       message->body = (char *) xrealloc (message->body, 0); */
+/*       message->bbytes = 0; */
 
       filename[0] = '\0';
       sprintf (filename, "%s/%s", boxname, d_content->d_name);
       fp = m_fopen (filename, "r");
       isheaders = 1;
       if (fp == NULL)
+	{
+	  free (message->headers);
+	  free (message->body);
+	  message->hbytes = 0;
+	  message->bbytes = 0;
 	  continue;
+	}
 
       fgets (buffer, BUFSIZ, fp);
-      if (config.format == NNML || config.format == NNMH)
-	{
-	  if (0 != strncmp ("X-From-Line: ", buffer, 13))
-	    {
-	      if (config.merr)
-		fprintf (stderr, "%s: %s: Not a Gnus folder message\n", 
-			 APPNAME, filename);
-	      fclose (fp);
-	      continue;
-	    }
-	}
+
+/*       if (config.format == NNML || config.format == NNMH) */
+/* 	{ */
+/* 	  if (0 != strncmp ("X-From-Line: ", buffer, 13)) */
+/* 	    { */
+/* 	      if (config.merr) */
+/* 		fprintf (stderr, "%s: %s: Not a Gnus folder message\n",  */
+/* 			 APPNAME, filename); */
+/* 	      fclose (fp); */
+/* 	      free (message->headers); */
+/* 	      free (message->body); */
+/* 	      message->hbytes = 0; */
+/* 	      message->bbytes = 0; */
+/* 	      continue; */
+/* 	    } */
+/* 	} */
       
       fseek (fp, 0, SEEK_SET);
+
       while (fgets (buffer, BUFSIZ, fp) != NULL)
 	{
 	  s = strlen (buffer);
@@ -136,14 +160,12 @@ message_t *mh_read_message (DIR *dp)
 	    } /* if */
 	  if (isheaders)
 	    {
-	      if (0 == strncmp ("Date: ", buffer, 6) && isheaders == 1)
-		message->date = parse_date (buffer);
 	      if (0 == strncasecmp ("From: ", buffer, 6))
 		have_from = 1;
-	      if (0 == strncasecmp ("To: ", buffer, 4))
-		have_to = 1;
-	      if (0 == strncasecmp ("Message-ID: ", buffer, 12))
-		have_message_id = 1;
+	      if (0 == strncasecmp ("Sender: ", buffer, 8))
+		have_sender = 1;
+	      if (0 == strncasecmp ("Date: ", buffer, 6))
+		have_date = 1;
 	      if (0 == strncasecmp ("Return-Path: ", buffer, 13))
 		{
 		  have_return_path = 1;
@@ -165,23 +187,30 @@ message_t *mh_read_message (DIR *dp)
 	      message->bbytes += s;
 	    } /* else */
 	} /* while */
-      if (config.format == MH)
-	{
-/*      if (!have_from || !have_to || !have_message_id || !have_return_path) */
-	  if (!have_from || !have_to || !have_message_id)
-	    {
-	      if (config.merr)
-		fprintf (stderr, "%s: %s: Not a RFC 2822 message\n",
-			 APPNAME, filename);
-	      fclose (fp);
-	      continue;
-	    }
-	}
-      message->filename = (char *) xstrdup (filename);
-      fclose (fp);
-      free (filename);
 
-      return message;
+      if ((!have_from && !have_sender)|| !have_date)
+	{
+	  if (config.merr)
+	    fprintf (stderr, "%s: %s: Not a RFC 2822 message\n",
+		     APPNAME, filename);
+	  fclose (fp);
+	  free (message->headers);
+	  message->headers = NULL;
+	  free (message->body);
+	  message->body = NULL;
+	  message->hbytes = 0;
+	  message->bbytes = 0;
+	  continue;
+	}
+
+      else
+	{
+	  message->filename = (char *) xstrdup (filename);
+	  fclose (fp);
+	  free (filename);
+
+	  return message;
+	}
     } /* for */
 } /* mh_read_message */
 
