@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: misc.c,v 1.7 2002/02/06 22:10:44 dspiljar Exp $ */
+  $Id: misc.c,v 1.13 2003/04/06 21:01:49 dspiljar Exp $ */
 
 #define _XOPEN_SOURCE  /* Pull in strptime(3) from time.h */
 #define _BSD_SOURCE    /* Compensate for _XOPEN_SOURCE to pull in strdup(3)
@@ -33,9 +33,9 @@
 #include "mboxgrep.h"
 #include "wrap.h"
 
-
 format_t
 folder_format (const char *name)
+     /* {{{  */
 {
   format_t f;
 
@@ -45,6 +45,10 @@ folder_format (const char *name)
     f = ZMBOX;
   else if (0 == strncasecmp (name, "gzmbox", 6))
     f = ZMBOX;
+  else if (0 == strncasecmp (name, "bzmbox", 5))
+    f = BZ2MBOX;
+  else if (0 == strncasecmp (name, "bz2mbox", 5))
+    f = BZ2MBOX;
   else if (0 == strncasecmp (name, "mh", 2))
     f = MH;
   else if (0 == strncasecmp (name, "nnml", 4))
@@ -62,8 +66,10 @@ folder_format (const char *name)
 
   return f;
 }
+/* }}} */
 
 lockmethod_t lock_method (const char *name)
+     /* {{{  */
 {
   lockmethod_t l;
 
@@ -85,35 +91,41 @@ lockmethod_t lock_method (const char *name)
 	fprintf (stderr, "mboxgrep: %s: unknown file locking method\n", name);
       exit (2);
     }
+
+  return l;
 }
+/* }}} */
 
-time_t parse_date(char *datestr)
-{
-  time_t t;
-  const char *fmt = "%d%n%b%n%Y%n%T";
-  int h, m;
-  struct tm tm;
-  char *str2, str1[BUFSIZ];
+/* time_t parse_date(char *datestr) */
+     /* {{{  */
+/* { */
+/*   time_t t; */
+/*   const char *fmt = "%d%n%b%n%Y%n%T"; */
+/*   int h, m; */
+/*   struct tm tm; */
+/*   char *str2, str1[BUFSIZ]; */
 
-  sscanf (datestr, "Date: %[^\r\n]", str1);
+/*   sscanf (datestr, "Date: %[^\r\n]", str1); */
 
-  str2 = (char *) strptime (str1, "%d%n%b%n%Y%n%T", &tm);
-  if (str2 == NULL)
-    str2 = (char *) strptime (str1, "%a, %d%n%b%n%Y%n%T", &tm);
-  if (str2 == NULL)
-    return (time_t) 0;
+/*   str2 = (char *) strptime (str1, "%d%n%b%n%Y%n%T", &tm); */
+/*   if (str2 == NULL) */
+/*     str2 = (char *) strptime (str1, "%a, %d%n%b%n%Y%n%T", &tm); */
+/*   if (str2 == NULL) */
+/*     return (time_t) 0; */
  
-  if (sscanf (str2, "%3d%2d", &h, &m) == 2)
-    {
-      tm.tm_hour -= h;
-      tm.tm_min -= (h >= 0 ? m : -m);
-      t = (time_t) mktime (&tm);
-    }
+/*   if (sscanf (str2, "%3d%2d", &h, &m) == 2) */
+/*     { */
+/*       tm.tm_hour -= h; */
+/*       tm.tm_min -= (h >= 0 ? m : -m); */
+/*       t = (time_t) mktime (&tm); */
+/*     } */
 
-  return t;
-}
+/*   return t; */
+/* } */
+/* }}} */
 
 char * parse_return_path(char *rpath)
+     /* {{{  */
 {
   char *blah1, blah2[BUFSIZ];
 
@@ -122,3 +134,4 @@ char * parse_return_path(char *rpath)
 
   return blah1;
 }
+/* }}} */
