@@ -1,6 +1,6 @@
 /* -*- C -*- 
    mboxgrep - scan mailbox for messages matching a regular expression
-   Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+   Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
    
    Mboxgrep is free software; you can redistribute it and/or modify it 
    under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
    along with mboxgrep; if not, write to the Free Software Foundation, 
    Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    
-   $Id: scan.c,v 1.12 2002/02/06 22:10:44 dspiljar Exp $ */
+   $Id: scan.c,v 1.21 2003/04/06 21:01:49 dspiljar Exp $ */
 
 #include <config.h>
 
@@ -60,15 +60,25 @@
 #include "maildir.h"
 #include "wrap.h"
 #include "md5.h"
+#ifdef HAVE_FTS_OPEN
+# include <sys/stat.h>
+# include <fts.h>
+#else
+# ifdef HAVE_FTW
+#  include <ftw.h>
+# endif /* HAVE_FTW */
+#endif /* HAVE_FTS_OPEN */
 
-void scan_mailbox(char path[])
+#ifdef HAVE_LIBDMALLOC
+#include <dmalloc.h>
+#endif /* HAVE_LIBDMALLOC */
+
+void scan_mailbox (char path[])
+     /* {{{  */
 {
-  static FILE *boxf, *out;
+  static FILE *outf;
   extern FILE *tmpp;
-#ifdef HAVE_LIBZ
-  static gzFile *zboxf;
-  extern gzFile *ztmpp;
-#endif /* HAVE_LIBZ */
+  static mbox_t *mbox, *out;
 #ifdef HAVE_LIBPCRE
   extern pcre *pcre_pattern;
   extern pcre_extra *hints;
@@ -110,19 +120,14 @@ void scan_mailbox(char path[])
   if (config.action == DELETE)
     delete = 1;
 
-  if (config.format == MBOX)
+  if ((config.format == MBOX) || (config.format == ZMBOX) ||
+      (config.format == BZ2MBOX))
     {
-      boxf = (FILE *) mbox_open(path, "r");
-      if (boxf == NULL) return;
+      mbox = (mbox_t *) mbox_open (path, "r");
+      if (mbox == NULL) return;
     }
-#ifdef HAVE_LIBZ
-  else if (config.format == ZMBOX)
-    {
-      zboxf = (gzFile *) gzmbox_open (path, "r");
-      if (zboxf == NULL) return;
-    }
-#endif /* HAVE_LIBZ */
-  else if ((config.format == MH) || (config.format == NNMH) || (config.format == NNML))
+  else if ((config.format == MH) || (config.format == NNMH) ||
+	   (config.format == NNML))
     {
       boxd = mh_open (path);
       if (boxd == NULL) return;
@@ -137,13 +142,11 @@ void scan_mailbox(char path[])
     {
       int res1 = 1, res2 = 1;
 
-      if (config.format == MBOX)
-	msg = (message_t *) mbox_read_message (boxf);
-#ifdef HAVE_LIBZ
-      if (config.format == ZMBOX)
-	msg = (message_t *) gzmbox_read_message (zboxf);
-#endif /* HAVE_LIBZ */
-      else if ((config.format == MH) || (config.format == NNMH) || (config.format == NNML))
+      if ((config.format == MBOX) || (config.format == ZMBOX) ||
+	  (config.format == BZ2MBOX))
+	msg = (message_t *) mbox_read_message (mbox);
+      else if ((config.format == MH) || (config.format == NNMH) ||
+	       (config.format == NNML))
 	msg = (message_t *) mh_read_message (boxd);
       else if (config.format == MAILDIR)
 	msg = (message_t *) maildir_read_message (maildird);
@@ -183,12 +186,16 @@ void scan_mailbox(char path[])
 	  if (config.action == DISPLAY)
 	    {
 	      if (config.format != MBOX && config.format != ZMBOX
+		  && config.format != BZ2MBOX
 		  && 0 != strncmp ("From ", msg->headers, 5))
 		{
 		  tt = time (NULL);
 		  ct = localtime (&tt);
 		  strftime (date_str, 80, "%a %b %d %H:%M:%S %Y", ct);
-		  fprintf (stdout, "From %s  %s\n", msg->from, date_str);
+		  if (msg->from)
+		    fprintf (stdout, "From %s  %s\n", msg->from, date_str);
+		  else
+		    fprintf (stdout, "From nobody  %s\n", date_str);
 		}
 	      fprintf (stdout, "%s\n%s", msg->headers, msg->body);
 	    }
@@ -196,19 +203,20 @@ void scan_mailbox(char path[])
 	    {
 	      if (config.format == MAILDIR)
 		maildir_write_message (msg, outboxname);
-	      else if (config.format == MH || config.format == NNMH || config.format == NNML)
+	      else if (config.format == MH || config.format == NNMH ||
+		       config.format == NNML)
 		mh_write_message (msg, outboxname);
 	      else if (config.format == MBOX)
 		{
 		  out = mbox_open (outboxname, "w");
-		  fprintf (out, "%s\n%s", msg->headers, msg->body);
+		  fprintf (out->fp, "%s\n%s", msg->headers, msg->body);
 		  mbox_close (out);
 		}
 	    }
 	  else if (config.action == PIPE)
 	    {
-	      out = popen (pipecmd, "w");
-	      if (out == NULL)
+	      outf = popen (pipecmd, "w");
+	      if (outf == NULL)
 		{
 		  if (config.merr)
 		    {
@@ -217,8 +225,8 @@ void scan_mailbox(char path[])
 		    }
 		  exit (2);
 		} /* if */
-	      fprintf (out, "%s\n%s", msg->headers, msg->body);
-	      pclose (out);
+	      fprintf (outf, "%s\n%s", msg->headers, msg->body);
+	      pclose (outf);
 	    }
 	  else if (config.action == COUNT)
 	    ++count;
@@ -233,19 +241,19 @@ void scan_mailbox(char path[])
 	      baz = strlen (msg->headers);
 	      for (;;)
 		{
-		  len = gzwrite (ztmpp, (msg->headers+quux), 
+		  len = gzwrite (tmpp, (msg->headers+quux), 
 			 	 (((quux + BUFLEN) < baz) ? BUFLEN : 
 				  (baz - quux)));
 		  quux += len;
 		  if (quux == baz)
 		    break;
 		}
-	      gzwrite(ztmpp, "\n", 1);
+	      gzwrite(tmpp, "\n", 1);
 	      quux = 0;
 	      baz = strlen(msg->body);
 	      for (;;)
 		{
-		  len = gzwrite(ztmpp, (msg->body+quux), 
+		  len = gzwrite(tmpp, (msg->body+quux), 
 				(((quux + BUFLEN) < baz) ? BUFLEN : 
 				 (baz - quux)));
 		  quux += len;
@@ -256,28 +264,66 @@ void scan_mailbox(char path[])
 #endif /* HAVE_LIBZ */
 	} /* if */
       else if (((((res1 == 0) | (res2 == 0)) ^ config.invert) && delete) &&
-	       ((config.format == MH) || (config.format == NNMH) 
-		|| (config.format == NNML) || (config.format == MAILDIR)))
+	       ((config.format == MH) || (config.format == NNMH) || 
+		(config.format == NNML) || (config.format == MAILDIR)))
 	m_unlink(msg->filename);
+
       free(msg->body);
       free(msg->headers);
       free(msg);
     } /* for */
-  if (config.format == MBOX)
-    mbox_close(boxf);
-#ifdef HAVE_LIBZ
-  if (config.format == ZMBOX)
-    gzmbox_close(zboxf);
-#endif /* HAVE_LIBZ */
-  else if ((config.format == MH) || (config.format == NNMH) || (config.format == NNML))
+  if ((config.format == MBOX) || (config.format == ZMBOX) ||
+      (config.format == BZ2MBOX))
+    mbox_close (mbox);
+  else if ((config.format == MH) || (config.format == NNMH) ||
+	   (config.format == NNML))
     mh_close(boxd);
-} /* scan_mailbox */
+}
+/* }}} */
+
+void recursive_scan (char path[])
+     /* {{{  */
+
+{
+#ifdef HAVE_FTS_OPEN
+  FTS *ftsfoo;
+  FTSENT *ftsbar;
+#endif /* HAVE_FTS_OPEN */
+
+#ifdef HAVE_FTS_OPEN
+  {
+    char *p[2];
+
+    p[0] = strdup (path);
+    p[1] = 0;
+
+    ftsfoo = fts_open (p, FTS_NOCHDIR, NULL);
+
+    if (ftsfoo == NULL)
+      {
+	/* fixme (?) */
+	perror(APPNAME);
+	exit (2);
+      }
+
+    while ((ftsbar = fts_read (ftsfoo)))
+      scan_mailbox (ftsbar->fts_path);
+
+    fts_close (ftsfoo);
+  }
+#else
+  ftw (path, (void *) scan_mailbox, 1);
+#endif /* HAVE_FTS_OPEN */
+}
+
+/* }}} */
 
 int md5_check_message (char *body, checksum_t *chksum)
+     /* {{{  */
 {
   struct md5_ctx a;
   unsigned char b[16];
-  int i,x;
+  int i;
 
   md5_init_ctx (&a);
   if (body == NULL)
@@ -300,3 +346,4 @@ int md5_check_message (char *body, checksum_t *chksum)
 
   return 0;
 }
+/* }}} */
