@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002, 2003  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: wrap.c,v 1.9 2002/02/06 22:10:44 dspiljar Exp $ */
+  $Id: wrap.c,v 1.12 2003/04/06 23:24:04 dspiljar Exp $ */
 
 #include <config.h>
 #include <unistd.h>
@@ -40,6 +40,9 @@
 #  include <ndir.h>
 # endif /* HAVE_NDIR_H */
 #endif /* HAVE_DIRENT_H */
+#ifdef HAVE_LIBZ
+#include <zlib.h>
+#endif /* HAVE_LIBZ */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -52,7 +55,6 @@
 #define APPNAME "mboxgrep"
 #endif
 
-
 int m_open (const char *pathname, int flags, mode_t mode)
 {
   int blah;
@@ -103,6 +105,23 @@ FILE *m_fdopen (int fildes, const char *mode)
   return blah;
 }
 
+#ifdef HAVE_LIBZ
+
+gzFile *m_gzdopen (int fildes, const char *mode)
+{
+  gzFile *blah;
+
+  blah = gzdopen (fildes, mode);
+  if (blah == NULL)
+    {
+      if (config.merr)
+	perror (APPNAME);
+    }
+  return blah;
+}
+
+#endif /* HAVE_LIBZ */
+
 DIR *m_opendir (const char *name)
 {
   DIR *blah;
@@ -119,6 +138,8 @@ DIR *m_opendir (const char *name)
   return blah;
 }
 
+#ifndef HAVE_LIBDMALLOC
+
 void *xmalloc (size_t size)
 {
   void *foo;
@@ -175,6 +196,8 @@ char *xstrdup (const char *s)
   return foo;
 }
 
+#endif /* HAVE_LIBDMALLOC */
+
 int m_unlink (const char *pathname)
 {
   int baz;
@@ -190,3 +213,4 @@ int m_unlink (const char *pathname)
     }
   return baz;
 }
+
